# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineFru(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'board_mfg': 'str',
        'board_mfg_serial': 'str',
        'board_part_number': 'str',
        'chassis_part_number': 'str',
        'chassis_part_serial': 'str',
        'product_manufacturer': 'str',
        'product_part_number': 'str',
        'product_serial': 'str'
    }

    attribute_map = {
        'board_mfg': 'board_mfg',
        'board_mfg_serial': 'board_mfg_serial',
        'board_part_number': 'board_part_number',
        'chassis_part_number': 'chassis_part_number',
        'chassis_part_serial': 'chassis_part_serial',
        'product_manufacturer': 'product_manufacturer',
        'product_part_number': 'product_part_number',
        'product_serial': 'product_serial'
    }

    def __init__(self, board_mfg=None, board_mfg_serial=None, board_part_number=None, chassis_part_number=None, chassis_part_serial=None, product_manufacturer=None, product_part_number=None, product_serial=None):  # noqa: E501
        """V1MachineFru - a model defined in Swagger"""  # noqa: E501

        self._board_mfg = None
        self._board_mfg_serial = None
        self._board_part_number = None
        self._chassis_part_number = None
        self._chassis_part_serial = None
        self._product_manufacturer = None
        self._product_part_number = None
        self._product_serial = None
        self.discriminator = None

        if board_mfg is not None:
            self.board_mfg = board_mfg
        if board_mfg_serial is not None:
            self.board_mfg_serial = board_mfg_serial
        if board_part_number is not None:
            self.board_part_number = board_part_number
        if chassis_part_number is not None:
            self.chassis_part_number = chassis_part_number
        if chassis_part_serial is not None:
            self.chassis_part_serial = chassis_part_serial
        if product_manufacturer is not None:
            self.product_manufacturer = product_manufacturer
        if product_part_number is not None:
            self.product_part_number = product_part_number
        if product_serial is not None:
            self.product_serial = product_serial

    @property
    def board_mfg(self):
        """Gets the board_mfg of this V1MachineFru.  # noqa: E501

        the board mfg  # noqa: E501

        :return: The board_mfg of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._board_mfg

    @board_mfg.setter
    def board_mfg(self, board_mfg):
        """Sets the board_mfg of this V1MachineFru.

        the board mfg  # noqa: E501

        :param board_mfg: The board_mfg of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._board_mfg = board_mfg

    @property
    def board_mfg_serial(self):
        """Gets the board_mfg_serial of this V1MachineFru.  # noqa: E501

        the board mfg serial  # noqa: E501

        :return: The board_mfg_serial of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._board_mfg_serial

    @board_mfg_serial.setter
    def board_mfg_serial(self, board_mfg_serial):
        """Sets the board_mfg_serial of this V1MachineFru.

        the board mfg serial  # noqa: E501

        :param board_mfg_serial: The board_mfg_serial of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._board_mfg_serial = board_mfg_serial

    @property
    def board_part_number(self):
        """Gets the board_part_number of this V1MachineFru.  # noqa: E501

        the board part number  # noqa: E501

        :return: The board_part_number of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._board_part_number

    @board_part_number.setter
    def board_part_number(self, board_part_number):
        """Sets the board_part_number of this V1MachineFru.

        the board part number  # noqa: E501

        :param board_part_number: The board_part_number of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._board_part_number = board_part_number

    @property
    def chassis_part_number(self):
        """Gets the chassis_part_number of this V1MachineFru.  # noqa: E501

        the chassis part number  # noqa: E501

        :return: The chassis_part_number of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._chassis_part_number

    @chassis_part_number.setter
    def chassis_part_number(self, chassis_part_number):
        """Sets the chassis_part_number of this V1MachineFru.

        the chassis part number  # noqa: E501

        :param chassis_part_number: The chassis_part_number of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._chassis_part_number = chassis_part_number

    @property
    def chassis_part_serial(self):
        """Gets the chassis_part_serial of this V1MachineFru.  # noqa: E501

        the chassis part serial  # noqa: E501

        :return: The chassis_part_serial of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._chassis_part_serial

    @chassis_part_serial.setter
    def chassis_part_serial(self, chassis_part_serial):
        """Sets the chassis_part_serial of this V1MachineFru.

        the chassis part serial  # noqa: E501

        :param chassis_part_serial: The chassis_part_serial of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._chassis_part_serial = chassis_part_serial

    @property
    def product_manufacturer(self):
        """Gets the product_manufacturer of this V1MachineFru.  # noqa: E501

        the product manufacturer  # noqa: E501

        :return: The product_manufacturer of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._product_manufacturer

    @product_manufacturer.setter
    def product_manufacturer(self, product_manufacturer):
        """Sets the product_manufacturer of this V1MachineFru.

        the product manufacturer  # noqa: E501

        :param product_manufacturer: The product_manufacturer of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._product_manufacturer = product_manufacturer

    @property
    def product_part_number(self):
        """Gets the product_part_number of this V1MachineFru.  # noqa: E501

        the product part number  # noqa: E501

        :return: The product_part_number of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._product_part_number

    @product_part_number.setter
    def product_part_number(self, product_part_number):
        """Sets the product_part_number of this V1MachineFru.

        the product part number  # noqa: E501

        :param product_part_number: The product_part_number of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._product_part_number = product_part_number

    @property
    def product_serial(self):
        """Gets the product_serial of this V1MachineFru.  # noqa: E501

        the product serial  # noqa: E501

        :return: The product_serial of this V1MachineFru.  # noqa: E501
        :rtype: str
        """
        return self._product_serial

    @product_serial.setter
    def product_serial(self, product_serial):
        """Sets the product_serial of this V1MachineFru.

        the product serial  # noqa: E501

        :param product_serial: The product_serial of this V1MachineFru.  # noqa: E501
        :type: str
        """

        self._product_serial = product_serial

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineFru, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineFru):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from metal_python.api.partition_api import PartitionApi
from metal_python.api.firewall_api import FirewallApi
from metal_python.api.health_api import HealthApi
from metal_python.api.image_api import ImageApi
from metal_python.api.ip_api import IpApi
from metal_python.api.machine_api import MachineApi
from metal_python.api.network_api import NetworkApi
from metal_python.api.project_api import ProjectApi
from metal_python.api.size_api import SizeApi
from metal_python.api.switch_api import SwitchApi
from metal_python.api.version_api import VersionApi

# import ApiClient
from metal_python.api_client import ApiClient
from metal_python.configuration import Configuration
# import models into sdk package
from metal_python.models.httperrors_http_error_response import HttperrorsHTTPErrorResponse
from metal_python.models.rest_status import RestStatus
from metal_python.models.rest_version import RestVersion
from metal_python.models.v1_bgp_filter import V1BGPFilter
from metal_python.models.v1_boot_info import V1BootInfo
from metal_python.models.v1_chassis_identify_led_state import V1ChassisIdentifyLEDState
from metal_python.models.v1_empty_body import V1EmptyBody
from metal_python.models.v1_firewall_create_request import V1FirewallCreateRequest
from metal_python.models.v1_firewall_find_request import V1FirewallFindRequest
from metal_python.models.v1_firewall_response import V1FirewallResponse
from metal_python.models.v1_ip_allocate_request import V1IPAllocateRequest
from metal_python.models.v1_ip_find_request import V1IPFindRequest
from metal_python.models.v1_ip_response import V1IPResponse
from metal_python.models.v1_ip_update_request import V1IPUpdateRequest
from metal_python.models.v1_image_create_request import V1ImageCreateRequest
from metal_python.models.v1_image_response import V1ImageResponse
from metal_python.models.v1_image_update_request import V1ImageUpdateRequest
from metal_python.models.v1_machine_abort_reinstall_request import V1MachineAbortReinstallRequest
from metal_python.models.v1_machine_allocate_request import V1MachineAllocateRequest
from metal_python.models.v1_machine_allocation import V1MachineAllocation
from metal_python.models.v1_machine_allocation_network import V1MachineAllocationNetwork
from metal_python.models.v1_machine_bios import V1MachineBIOS
from metal_python.models.v1_machine_block_device import V1MachineBlockDevice
from metal_python.models.v1_machine_disk_partition import V1MachineDiskPartition
from metal_python.models.v1_machine_finalize_allocation_request import V1MachineFinalizeAllocationRequest
from metal_python.models.v1_machine_find_request import V1MachineFindRequest
from metal_python.models.v1_machine_fru import V1MachineFru
from metal_python.models.v1_machine_hardware import V1MachineHardware
from metal_python.models.v1_machine_hardware_extended import V1MachineHardwareExtended
from metal_python.models.v1_machine_ipmi import V1MachineIPMI
from metal_python.models.v1_machine_ipmi_response import V1MachineIPMIResponse
from metal_python.models.v1_machine_ipmi_report import V1MachineIpmiReport
from metal_python.models.v1_machine_ipmi_report_response import V1MachineIpmiReportResponse
from metal_python.models.v1_machine_network import V1MachineNetwork
from metal_python.models.v1_machine_nic import V1MachineNic
from metal_python.models.v1_machine_nic_extended import V1MachineNicExtended
from metal_python.models.v1_machine_provisioning_event import V1MachineProvisioningEvent
from metal_python.models.v1_machine_recent_provisioning_events import V1MachineRecentProvisioningEvents
from metal_python.models.v1_machine_register_request import V1MachineRegisterRequest
from metal_python.models.v1_machine_reinstall_request import V1MachineReinstallRequest
from metal_python.models.v1_machine_response import V1MachineResponse
from metal_python.models.v1_machine_state import V1MachineState
from metal_python.models.v1_meta import V1Meta
from metal_python.models.v1_network_allocate_request import V1NetworkAllocateRequest
from metal_python.models.v1_network_create_request import V1NetworkCreateRequest
from metal_python.models.v1_network_find_request import V1NetworkFindRequest
from metal_python.models.v1_network_response import V1NetworkResponse
from metal_python.models.v1_network_update_request import V1NetworkUpdateRequest
from metal_python.models.v1_network_usage import V1NetworkUsage
from metal_python.models.v1_partition_boot_configuration import V1PartitionBootConfiguration
from metal_python.models.v1_partition_capacity import V1PartitionCapacity
from metal_python.models.v1_partition_create_request import V1PartitionCreateRequest
from metal_python.models.v1_partition_response import V1PartitionResponse
from metal_python.models.v1_partition_update_request import V1PartitionUpdateRequest
from metal_python.models.v1_project_create_request import V1ProjectCreateRequest
from metal_python.models.v1_project_find_request import V1ProjectFindRequest
from metal_python.models.v1_project_response import V1ProjectResponse
from metal_python.models.v1_project_update_request import V1ProjectUpdateRequest
from metal_python.models.v1_quota import V1Quota
from metal_python.models.v1_quota_set import V1QuotaSet
from metal_python.models.v1_server_capacity import V1ServerCapacity
from metal_python.models.v1_size_constraint import V1SizeConstraint
from metal_python.models.v1_size_constraint_matching_log import V1SizeConstraintMatchingLog
from metal_python.models.v1_size_create_request import V1SizeCreateRequest
from metal_python.models.v1_size_matching_log import V1SizeMatchingLog
from metal_python.models.v1_size_response import V1SizeResponse
from metal_python.models.v1_size_update_request import V1SizeUpdateRequest
from metal_python.models.v1_switch_connection import V1SwitchConnection
from metal_python.models.v1_switch_nic import V1SwitchNic
from metal_python.models.v1_switch_notify_request import V1SwitchNotifyRequest
from metal_python.models.v1_switch_register_request import V1SwitchRegisterRequest
from metal_python.models.v1_switch_response import V1SwitchResponse
from metal_python.models.v1_switch_sync import V1SwitchSync
from metal_python.models.v1_switch_update_request import V1SwitchUpdateRequest



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.models.v1_size_response import V1SizeResponse  # noqa: E501
from metal_python.rest import ApiException


class TestV1SizeResponse(unittest.TestCase):
    """V1SizeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1SizeResponse(self):
        """Test V1SizeResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = metal_python.models.v1_size_response.V1SizeResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1IPUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'ipaddress': 'str',
        'name': 'str',
        'tags': 'list[str]',
        'type': 'str'
    }

    attribute_map = {
        'description': 'description',
        'ipaddress': 'ipaddress',
        'name': 'name',
        'tags': 'tags',
        'type': 'type'
    }

    def __init__(self, description=None, ipaddress=None, name=None, tags=None, type=None):  # noqa: E501
        """V1IPUpdateRequest - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._ipaddress = None
        self._name = None
        self._tags = None
        self._type = None
        self.discriminator = None

        if description is not None:
            self.description = description
        self.ipaddress = ipaddress
        if name is not None:
            self.name = name
        if tags is not None:
            self.tags = tags
        self.type = type

    @property
    def description(self):
        """Gets the description of this V1IPUpdateRequest.  # noqa: E501

        a description for this entity  # noqa: E501

        :return: The description of this V1IPUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1IPUpdateRequest.

        a description for this entity  # noqa: E501

        :param description: The description of this V1IPUpdateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ipaddress(self):
        """Gets the ipaddress of this V1IPUpdateRequest.  # noqa: E501

        the address (ipv4 or ipv6) of this ip  # noqa: E501

        :return: The ipaddress of this V1IPUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipaddress

    @ipaddress.setter
    def ipaddress(self, ipaddress):
        """Sets the ipaddress of this V1IPUpdateRequest.

        the address (ipv4 or ipv6) of this ip  # noqa: E501

        :param ipaddress: The ipaddress of this V1IPUpdateRequest.  # noqa: E501
        :type: str
        """
        if ipaddress is None:
            raise ValueError("Invalid value for `ipaddress`, must not be `None`")  # noqa: E501

        self._ipaddress = ipaddress

    @property
    def name(self):
        """Gets the name of this V1IPUpdateRequest.  # noqa: E501

        a readable name for this entity  # noqa: E501

        :return: The name of this V1IPUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1IPUpdateRequest.

        a readable name for this entity  # noqa: E501

        :param name: The name of this V1IPUpdateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def tags(self):
        """Gets the tags of this V1IPUpdateRequest.  # noqa: E501

        free tags that you associate with this ip.  # noqa: E501

        :return: The tags of this V1IPUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1IPUpdateRequest.

        free tags that you associate with this ip.  # noqa: E501

        :param tags: The tags of this V1IPUpdateRequest.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this V1IPUpdateRequest.  # noqa: E501

        the ip type, ephemeral leads to automatic cleanup of the ip address, static will enable re-use of the ip at a later point in time  # noqa: E501

        :return: The type of this V1IPUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1IPUpdateRequest.

        the ip type, ephemeral leads to automatic cleanup of the ip address, static will enable re-use of the ip at a later point in time  # noqa: E501

        :param type: The type of this V1IPUpdateRequest.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["ephemeral", "static"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1IPUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1IPUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1NetworkFindRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destinationprefixes': 'list[str]',
        'id': 'str',
        'labels': 'dict(str, str)',
        'name': 'str',
        'nat': 'bool',
        'parentnetworkid': 'str',
        'partitionid': 'str',
        'prefixes': 'list[str]',
        'privatesuper': 'bool',
        'projectid': 'str',
        'underlay': 'bool',
        'vrf': 'int'
    }

    attribute_map = {
        'destinationprefixes': 'destinationprefixes',
        'id': 'id',
        'labels': 'labels',
        'name': 'name',
        'nat': 'nat',
        'parentnetworkid': 'parentnetworkid',
        'partitionid': 'partitionid',
        'prefixes': 'prefixes',
        'privatesuper': 'privatesuper',
        'projectid': 'projectid',
        'underlay': 'underlay',
        'vrf': 'vrf'
    }

    def __init__(self, destinationprefixes=None, id=None, labels=None, name=None, nat=None, parentnetworkid=None, partitionid=None, prefixes=None, privatesuper=None, projectid=None, underlay=None, vrf=None):  # noqa: E501
        """V1NetworkFindRequest - a model defined in Swagger"""  # noqa: E501

        self._destinationprefixes = None
        self._id = None
        self._labels = None
        self._name = None
        self._nat = None
        self._parentnetworkid = None
        self._partitionid = None
        self._prefixes = None
        self._privatesuper = None
        self._projectid = None
        self._underlay = None
        self._vrf = None
        self.discriminator = None

        if destinationprefixes is not None:
            self.destinationprefixes = destinationprefixes
        if id is not None:
            self.id = id
        if labels is not None:
            self.labels = labels
        if name is not None:
            self.name = name
        if nat is not None:
            self.nat = nat
        if parentnetworkid is not None:
            self.parentnetworkid = parentnetworkid
        if partitionid is not None:
            self.partitionid = partitionid
        if prefixes is not None:
            self.prefixes = prefixes
        if privatesuper is not None:
            self.privatesuper = privatesuper
        if projectid is not None:
            self.projectid = projectid
        if underlay is not None:
            self.underlay = underlay
        if vrf is not None:
            self.vrf = vrf

    @property
    def destinationprefixes(self):
        """Gets the destinationprefixes of this V1NetworkFindRequest.  # noqa: E501


        :return: The destinationprefixes of this V1NetworkFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._destinationprefixes

    @destinationprefixes.setter
    def destinationprefixes(self, destinationprefixes):
        """Sets the destinationprefixes of this V1NetworkFindRequest.


        :param destinationprefixes: The destinationprefixes of this V1NetworkFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._destinationprefixes = destinationprefixes

    @property
    def id(self):
        """Gets the id of this V1NetworkFindRequest.  # noqa: E501


        :return: The id of this V1NetworkFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1NetworkFindRequest.


        :param id: The id of this V1NetworkFindRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def labels(self):
        """Gets the labels of this V1NetworkFindRequest.  # noqa: E501


        :return: The labels of this V1NetworkFindRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this V1NetworkFindRequest.


        :param labels: The labels of this V1NetworkFindRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this V1NetworkFindRequest.  # noqa: E501


        :return: The name of this V1NetworkFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1NetworkFindRequest.


        :param name: The name of this V1NetworkFindRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def nat(self):
        """Gets the nat of this V1NetworkFindRequest.  # noqa: E501


        :return: The nat of this V1NetworkFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._nat

    @nat.setter
    def nat(self, nat):
        """Sets the nat of this V1NetworkFindRequest.


        :param nat: The nat of this V1NetworkFindRequest.  # noqa: E501
        :type: bool
        """

        self._nat = nat

    @property
    def parentnetworkid(self):
        """Gets the parentnetworkid of this V1NetworkFindRequest.  # noqa: E501


        :return: The parentnetworkid of this V1NetworkFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._parentnetworkid

    @parentnetworkid.setter
    def parentnetworkid(self, parentnetworkid):
        """Sets the parentnetworkid of this V1NetworkFindRequest.


        :param parentnetworkid: The parentnetworkid of this V1NetworkFindRequest.  # noqa: E501
        :type: str
        """

        self._parentnetworkid = parentnetworkid

    @property
    def partitionid(self):
        """Gets the partitionid of this V1NetworkFindRequest.  # noqa: E501


        :return: The partitionid of this V1NetworkFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._partitionid

    @partitionid.setter
    def partitionid(self, partitionid):
        """Sets the partitionid of this V1NetworkFindRequest.


        :param partitionid: The partitionid of this V1NetworkFindRequest.  # noqa: E501
        :type: str
        """

        self._partitionid = partitionid

    @property
    def prefixes(self):
        """Gets the prefixes of this V1NetworkFindRequest.  # noqa: E501


        :return: The prefixes of this V1NetworkFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this V1NetworkFindRequest.


        :param prefixes: The prefixes of this V1NetworkFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._prefixes = prefixes

    @property
    def privatesuper(self):
        """Gets the privatesuper of this V1NetworkFindRequest.  # noqa: E501


        :return: The privatesuper of this V1NetworkFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._privatesuper

    @privatesuper.setter
    def privatesuper(self, privatesuper):
        """Sets the privatesuper of this V1NetworkFindRequest.


        :param privatesuper: The privatesuper of this V1NetworkFindRequest.  # noqa: E501
        :type: bool
        """

        self._privatesuper = privatesuper

    @property
    def projectid(self):
        """Gets the projectid of this V1NetworkFindRequest.  # noqa: E501


        :return: The projectid of this V1NetworkFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._projectid

    @projectid.setter
    def projectid(self, projectid):
        """Sets the projectid of this V1NetworkFindRequest.


        :param projectid: The projectid of this V1NetworkFindRequest.  # noqa: E501
        :type: str
        """

        self._projectid = projectid

    @property
    def underlay(self):
        """Gets the underlay of this V1NetworkFindRequest.  # noqa: E501


        :return: The underlay of this V1NetworkFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._underlay

    @underlay.setter
    def underlay(self, underlay):
        """Sets the underlay of this V1NetworkFindRequest.


        :param underlay: The underlay of this V1NetworkFindRequest.  # noqa: E501
        :type: bool
        """

        self._underlay = underlay

    @property
    def vrf(self):
        """Gets the vrf of this V1NetworkFindRequest.  # noqa: E501


        :return: The vrf of this V1NetworkFindRequest.  # noqa: E501
        :rtype: int
        """
        return self._vrf

    @vrf.setter
    def vrf(self, vrf):
        """Sets the vrf of this V1NetworkFindRequest.


        :param vrf: The vrf of this V1NetworkFindRequest.  # noqa: E501
        :type: int
        """

        self._vrf = vrf

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1NetworkFindRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkFindRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineBlockDevice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'partitions': 'list[V1MachineDiskPartition]',
        'primary': 'bool',
        'size': 'int'
    }

    attribute_map = {
        'name': 'name',
        'partitions': 'partitions',
        'primary': 'primary',
        'size': 'size'
    }

    def __init__(self, name=None, partitions=None, primary=None, size=None):  # noqa: E501
        """V1MachineBlockDevice - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._partitions = None
        self._primary = None
        self._size = None
        self.discriminator = None

        self.name = name
        if partitions is not None:
            self.partitions = partitions
        self.primary = primary
        self.size = size

    @property
    def name(self):
        """Gets the name of this V1MachineBlockDevice.  # noqa: E501

        the name of this block device  # noqa: E501

        :return: The name of this V1MachineBlockDevice.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1MachineBlockDevice.

        the name of this block device  # noqa: E501

        :param name: The name of this V1MachineBlockDevice.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def partitions(self):
        """Gets the partitions of this V1MachineBlockDevice.  # noqa: E501

        the partitions of this disk  # noqa: E501

        :return: The partitions of this V1MachineBlockDevice.  # noqa: E501
        :rtype: list[V1MachineDiskPartition]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this V1MachineBlockDevice.

        the partitions of this disk  # noqa: E501

        :param partitions: The partitions of this V1MachineBlockDevice.  # noqa: E501
        :type: list[V1MachineDiskPartition]
        """

        self._partitions = partitions

    @property
    def primary(self):
        """Gets the primary of this V1MachineBlockDevice.  # noqa: E501

        whether this disk has the OS installed  # noqa: E501

        :return: The primary of this V1MachineBlockDevice.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this V1MachineBlockDevice.

        whether this disk has the OS installed  # noqa: E501

        :param primary: The primary of this V1MachineBlockDevice.  # noqa: E501
        :type: bool
        """
        if primary is None:
            raise ValueError("Invalid value for `primary`, must not be `None`")  # noqa: E501

        self._primary = primary

    @property
    def size(self):
        """Gets the size of this V1MachineBlockDevice.  # noqa: E501

        the size of this block device  # noqa: E501

        :return: The size of this V1MachineBlockDevice.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1MachineBlockDevice.

        the size of this block device  # noqa: E501

        :param size: The size of this V1MachineBlockDevice.  # noqa: E501
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineBlockDevice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineBlockDevice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineAllocationNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'autoacquire': 'bool',
        'networkid': 'str'
    }

    attribute_map = {
        'autoacquire': 'autoacquire',
        'networkid': 'networkid'
    }

    def __init__(self, autoacquire=None, networkid=None):  # noqa: E501
        """V1MachineAllocationNetwork - a model defined in Swagger"""  # noqa: E501

        self._autoacquire = None
        self._networkid = None
        self.discriminator = None

        self.autoacquire = autoacquire
        self.networkid = networkid

    @property
    def autoacquire(self):
        """Gets the autoacquire of this V1MachineAllocationNetwork.  # noqa: E501

        will automatically acquire an ip in this network if set to true, default is true  # noqa: E501

        :return: The autoacquire of this V1MachineAllocationNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._autoacquire

    @autoacquire.setter
    def autoacquire(self, autoacquire):
        """Sets the autoacquire of this V1MachineAllocationNetwork.

        will automatically acquire an ip in this network if set to true, default is true  # noqa: E501

        :param autoacquire: The autoacquire of this V1MachineAllocationNetwork.  # noqa: E501
        :type: bool
        """
        if autoacquire is None:
            raise ValueError("Invalid value for `autoacquire`, must not be `None`")  # noqa: E501

        self._autoacquire = autoacquire

    @property
    def networkid(self):
        """Gets the networkid of this V1MachineAllocationNetwork.  # noqa: E501

        the id of the network that this machine will be placed in  # noqa: E501

        :return: The networkid of this V1MachineAllocationNetwork.  # noqa: E501
        :rtype: str
        """
        return self._networkid

    @networkid.setter
    def networkid(self, networkid):
        """Sets the networkid of this V1MachineAllocationNetwork.

        the id of the network that this machine will be placed in  # noqa: E501

        :param networkid: The networkid of this V1MachineAllocationNetwork.  # noqa: E501
        :type: str
        """
        if networkid is None:
            raise ValueError("Invalid value for `networkid`, must not be `None`")  # noqa: E501

        self._networkid = networkid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineAllocationNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineAllocationNetwork):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.size_api import SizeApi  # noqa: E501
from metal_python.rest import ApiException


class TestSizeApi(unittest.TestCase):
    """SizeApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.size_api.SizeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_size(self):
        """Test case for create_size

        create a size. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_size(self):
        """Test case for delete_size

        deletes an size and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_size(self):
        """Test case for find_size

        get size by id  # noqa: E501
        """
        pass

    def test_from_hardware(self):
        """Test case for from_hardware

        Searches all sizes for one to match the given hardwarespecs. If nothing is found, a list of entries is returned which describe the constraint which did not match  # noqa: E501
        """
        pass

    def test_list_sizes(self):
        """Test case for list_sizes

        get all sizes  # noqa: E501
        """
        pass

    def test_update_size(self):
        """Test case for update_size

        updates a size. if the size was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1FirewallResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation': 'V1MachineAllocation',
        'bios': 'V1MachineBIOS',
        'changed': 'datetime',
        'created': 'datetime',
        'description': 'str',
        'events': 'V1MachineRecentProvisioningEvents',
        'hardware': 'V1MachineHardware',
        'id': 'str',
        'ledstate': 'V1ChassisIdentifyLEDState',
        'liveliness': 'str',
        'name': 'str',
        'partition': 'V1PartitionResponse',
        'rackid': 'str',
        'size': 'V1SizeResponse',
        'state': 'V1MachineState',
        'tags': 'list[str]'
    }

    attribute_map = {
        'allocation': 'allocation',
        'bios': 'bios',
        'changed': 'changed',
        'created': 'created',
        'description': 'description',
        'events': 'events',
        'hardware': 'hardware',
        'id': 'id',
        'ledstate': 'ledstate',
        'liveliness': 'liveliness',
        'name': 'name',
        'partition': 'partition',
        'rackid': 'rackid',
        'size': 'size',
        'state': 'state',
        'tags': 'tags'
    }

    def __init__(self, allocation=None, bios=None, changed=None, created=None, description=None, events=None, hardware=None, id=None, ledstate=None, liveliness=None, name=None, partition=None, rackid=None, size=None, state=None, tags=None):  # noqa: E501
        """V1FirewallResponse - a model defined in Swagger"""  # noqa: E501

        self._allocation = None
        self._bios = None
        self._changed = None
        self._created = None
        self._description = None
        self._events = None
        self._hardware = None
        self._id = None
        self._ledstate = None
        self._liveliness = None
        self._name = None
        self._partition = None
        self._rackid = None
        self._size = None
        self._state = None
        self._tags = None
        self.discriminator = None

        if allocation is not None:
            self.allocation = allocation
        self.bios = bios
        if changed is not None:
            self.changed = changed
        if created is not None:
            self.created = created
        if description is not None:
            self.description = description
        self.events = events
        self.hardware = hardware
        self.id = id
        self.ledstate = ledstate
        self.liveliness = liveliness
        if name is not None:
            self.name = name
        if partition is not None:
            self.partition = partition
        if rackid is not None:
            self.rackid = rackid
        if size is not None:
            self.size = size
        self.state = state
        self.tags = tags

    @property
    def allocation(self):
        """Gets the allocation of this V1FirewallResponse.  # noqa: E501

        the allocation data of an allocated machine  # noqa: E501

        :return: The allocation of this V1FirewallResponse.  # noqa: E501
        :rtype: V1MachineAllocation
        """
        return self._allocation

    @allocation.setter
    def allocation(self, allocation):
        """Sets the allocation of this V1FirewallResponse.

        the allocation data of an allocated machine  # noqa: E501

        :param allocation: The allocation of this V1FirewallResponse.  # noqa: E501
        :type: V1MachineAllocation
        """

        self._allocation = allocation

    @property
    def bios(self):
        """Gets the bios of this V1FirewallResponse.  # noqa: E501

        bios information of this machine  # noqa: E501

        :return: The bios of this V1FirewallResponse.  # noqa: E501
        :rtype: V1MachineBIOS
        """
        return self._bios

    @bios.setter
    def bios(self, bios):
        """Sets the bios of this V1FirewallResponse.

        bios information of this machine  # noqa: E501

        :param bios: The bios of this V1FirewallResponse.  # noqa: E501
        :type: V1MachineBIOS
        """
        if bios is None:
            raise ValueError("Invalid value for `bios`, must not be `None`")  # noqa: E501

        self._bios = bios

    @property
    def changed(self):
        """Gets the changed of this V1FirewallResponse.  # noqa: E501

        the last changed timestamp of this entity  # noqa: E501

        :return: The changed of this V1FirewallResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._changed

    @changed.setter
    def changed(self, changed):
        """Sets the changed of this V1FirewallResponse.

        the last changed timestamp of this entity  # noqa: E501

        :param changed: The changed of this V1FirewallResponse.  # noqa: E501
        :type: datetime
        """

        self._changed = changed

    @property
    def created(self):
        """Gets the created of this V1FirewallResponse.  # noqa: E501

        the creation time of this entity  # noqa: E501

        :return: The created of this V1FirewallResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this V1FirewallResponse.

        the creation time of this entity  # noqa: E501

        :param created: The created of this V1FirewallResponse.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def description(self):
        """Gets the description of this V1FirewallResponse.  # noqa: E501

        a description for this entity  # noqa: E501

        :return: The description of this V1FirewallResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1FirewallResponse.

        a description for this entity  # noqa: E501

        :param description: The description of this V1FirewallResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def events(self):
        """Gets the events of this V1FirewallResponse.  # noqa: E501

        recent events of this machine during provisioning  # noqa: E501

        :return: The events of this V1FirewallResponse.  # noqa: E501
        :rtype: V1MachineRecentProvisioningEvents
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this V1FirewallResponse.

        recent events of this machine during provisioning  # noqa: E501

        :param events: The events of this V1FirewallResponse.  # noqa: E501
        :type: V1MachineRecentProvisioningEvents
        """
        if events is None:
            raise ValueError("Invalid value for `events`, must not be `None`")  # noqa: E501

        self._events = events

    @property
    def hardware(self):
        """Gets the hardware of this V1FirewallResponse.  # noqa: E501

        the hardware of this machine  # noqa: E501

        :return: The hardware of this V1FirewallResponse.  # noqa: E501
        :rtype: V1MachineHardware
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware):
        """Sets the hardware of this V1FirewallResponse.

        the hardware of this machine  # noqa: E501

        :param hardware: The hardware of this V1FirewallResponse.  # noqa: E501
        :type: V1MachineHardware
        """
        if hardware is None:
            raise ValueError("Invalid value for `hardware`, must not be `None`")  # noqa: E501

        self._hardware = hardware

    @property
    def id(self):
        """Gets the id of this V1FirewallResponse.  # noqa: E501

        the unique ID of this entity  # noqa: E501

        :return: The id of this V1FirewallResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1FirewallResponse.

        the unique ID of this entity  # noqa: E501

        :param id: The id of this V1FirewallResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ledstate(self):
        """Gets the ledstate of this V1FirewallResponse.  # noqa: E501

        the state of this chassis identify LED  # noqa: E501

        :return: The ledstate of this V1FirewallResponse.  # noqa: E501
        :rtype: V1ChassisIdentifyLEDState
        """
        return self._ledstate

    @ledstate.setter
    def ledstate(self, ledstate):
        """Sets the ledstate of this V1FirewallResponse.

        the state of this chassis identify LED  # noqa: E501

        :param ledstate: The ledstate of this V1FirewallResponse.  # noqa: E501
        :type: V1ChassisIdentifyLEDState
        """
        if ledstate is None:
            raise ValueError("Invalid value for `ledstate`, must not be `None`")  # noqa: E501

        self._ledstate = ledstate

    @property
    def liveliness(self):
        """Gets the liveliness of this V1FirewallResponse.  # noqa: E501

        the liveliness of this machine  # noqa: E501

        :return: The liveliness of this V1FirewallResponse.  # noqa: E501
        :rtype: str
        """
        return self._liveliness

    @liveliness.setter
    def liveliness(self, liveliness):
        """Sets the liveliness of this V1FirewallResponse.

        the liveliness of this machine  # noqa: E501

        :param liveliness: The liveliness of this V1FirewallResponse.  # noqa: E501
        :type: str
        """
        if liveliness is None:
            raise ValueError("Invalid value for `liveliness`, must not be `None`")  # noqa: E501

        self._liveliness = liveliness

    @property
    def name(self):
        """Gets the name of this V1FirewallResponse.  # noqa: E501

        a readable name for this entity  # noqa: E501

        :return: The name of this V1FirewallResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1FirewallResponse.

        a readable name for this entity  # noqa: E501

        :param name: The name of this V1FirewallResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def partition(self):
        """Gets the partition of this V1FirewallResponse.  # noqa: E501

        the partition assigned to this machine  # noqa: E501

        :return: The partition of this V1FirewallResponse.  # noqa: E501
        :rtype: V1PartitionResponse
        """
        return self._partition

    @partition.setter
    def partition(self, partition):
        """Sets the partition of this V1FirewallResponse.

        the partition assigned to this machine  # noqa: E501

        :param partition: The partition of this V1FirewallResponse.  # noqa: E501
        :type: V1PartitionResponse
        """

        self._partition = partition

    @property
    def rackid(self):
        """Gets the rackid of this V1FirewallResponse.  # noqa: E501

        the rack assigned to this machine  # noqa: E501

        :return: The rackid of this V1FirewallResponse.  # noqa: E501
        :rtype: str
        """
        return self._rackid

    @rackid.setter
    def rackid(self, rackid):
        """Sets the rackid of this V1FirewallResponse.

        the rack assigned to this machine  # noqa: E501

        :param rackid: The rackid of this V1FirewallResponse.  # noqa: E501
        :type: str
        """

        self._rackid = rackid

    @property
    def size(self):
        """Gets the size of this V1FirewallResponse.  # noqa: E501

        the size of this machine  # noqa: E501

        :return: The size of this V1FirewallResponse.  # noqa: E501
        :rtype: V1SizeResponse
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1FirewallResponse.

        the size of this machine  # noqa: E501

        :param size: The size of this V1FirewallResponse.  # noqa: E501
        :type: V1SizeResponse
        """

        self._size = size

    @property
    def state(self):
        """Gets the state of this V1FirewallResponse.  # noqa: E501

        the state of this machine  # noqa: E501

        :return: The state of this V1FirewallResponse.  # noqa: E501
        :rtype: V1MachineState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this V1FirewallResponse.

        the state of this machine  # noqa: E501

        :param state: The state of this V1FirewallResponse.  # noqa: E501
        :type: V1MachineState
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def tags(self):
        """Gets the tags of this V1FirewallResponse.  # noqa: E501

        tags for this machine  # noqa: E501

        :return: The tags of this V1FirewallResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1FirewallResponse.

        tags for this machine  # noqa: E501

        :param tags: The tags of this V1FirewallResponse.  # noqa: E501
        :type: list[str]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1FirewallResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1FirewallResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1NetworkResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'changed': 'datetime',
        'created': 'datetime',
        'description': 'str',
        'destinationprefixes': 'list[str]',
        'id': 'str',
        'labels': 'dict(str, str)',
        'name': 'str',
        'nat': 'bool',
        'parentnetworkid': 'str',
        'partitionid': 'str',
        'prefixes': 'list[str]',
        'privatesuper': 'bool',
        'projectid': 'str',
        'underlay': 'bool',
        'usage': 'V1NetworkUsage',
        'vrf': 'int',
        'vrfshared': 'bool'
    }

    attribute_map = {
        'changed': 'changed',
        'created': 'created',
        'description': 'description',
        'destinationprefixes': 'destinationprefixes',
        'id': 'id',
        'labels': 'labels',
        'name': 'name',
        'nat': 'nat',
        'parentnetworkid': 'parentnetworkid',
        'partitionid': 'partitionid',
        'prefixes': 'prefixes',
        'privatesuper': 'privatesuper',
        'projectid': 'projectid',
        'underlay': 'underlay',
        'usage': 'usage',
        'vrf': 'vrf',
        'vrfshared': 'vrfshared'
    }

    def __init__(self, changed=None, created=None, description=None, destinationprefixes=None, id=None, labels=None, name=None, nat=None, parentnetworkid=None, partitionid=None, prefixes=None, privatesuper=None, projectid=None, underlay=None, usage=None, vrf=None, vrfshared=None):  # noqa: E501
        """V1NetworkResponse - a model defined in Swagger"""  # noqa: E501

        self._changed = None
        self._created = None
        self._description = None
        self._destinationprefixes = None
        self._id = None
        self._labels = None
        self._name = None
        self._nat = None
        self._parentnetworkid = None
        self._partitionid = None
        self._prefixes = None
        self._privatesuper = None
        self._projectid = None
        self._underlay = None
        self._usage = None
        self._vrf = None
        self._vrfshared = None
        self.discriminator = None

        if changed is not None:
            self.changed = changed
        if created is not None:
            self.created = created
        if description is not None:
            self.description = description
        self.destinationprefixes = destinationprefixes
        self.id = id
        if labels is not None:
            self.labels = labels
        if name is not None:
            self.name = name
        self.nat = nat
        self.parentnetworkid = parentnetworkid
        if partitionid is not None:
            self.partitionid = partitionid
        self.prefixes = prefixes
        self.privatesuper = privatesuper
        if projectid is not None:
            self.projectid = projectid
        self.underlay = underlay
        self.usage = usage
        if vrf is not None:
            self.vrf = vrf
        if vrfshared is not None:
            self.vrfshared = vrfshared

    @property
    def changed(self):
        """Gets the changed of this V1NetworkResponse.  # noqa: E501

        the last changed timestamp of this entity  # noqa: E501

        :return: The changed of this V1NetworkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._changed

    @changed.setter
    def changed(self, changed):
        """Sets the changed of this V1NetworkResponse.

        the last changed timestamp of this entity  # noqa: E501

        :param changed: The changed of this V1NetworkResponse.  # noqa: E501
        :type: datetime
        """

        self._changed = changed

    @property
    def created(self):
        """Gets the created of this V1NetworkResponse.  # noqa: E501

        the creation time of this entity  # noqa: E501

        :return: The created of this V1NetworkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this V1NetworkResponse.

        the creation time of this entity  # noqa: E501

        :param created: The created of this V1NetworkResponse.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def description(self):
        """Gets the description of this V1NetworkResponse.  # noqa: E501

        a description for this entity  # noqa: E501

        :return: The description of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1NetworkResponse.

        a description for this entity  # noqa: E501

        :param description: The description of this V1NetworkResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def destinationprefixes(self):
        """Gets the destinationprefixes of this V1NetworkResponse.  # noqa: E501

        the destination prefixes of this network  # noqa: E501

        :return: The destinationprefixes of this V1NetworkResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._destinationprefixes

    @destinationprefixes.setter
    def destinationprefixes(self, destinationprefixes):
        """Sets the destinationprefixes of this V1NetworkResponse.

        the destination prefixes of this network  # noqa: E501

        :param destinationprefixes: The destinationprefixes of this V1NetworkResponse.  # noqa: E501
        :type: list[str]
        """
        if destinationprefixes is None:
            raise ValueError("Invalid value for `destinationprefixes`, must not be `None`")  # noqa: E501

        self._destinationprefixes = destinationprefixes

    @property
    def id(self):
        """Gets the id of this V1NetworkResponse.  # noqa: E501

        the unique ID of this entity  # noqa: E501

        :return: The id of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1NetworkResponse.

        the unique ID of this entity  # noqa: E501

        :param id: The id of this V1NetworkResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def labels(self):
        """Gets the labels of this V1NetworkResponse.  # noqa: E501

        free labels that you associate with this network.  # noqa: E501

        :return: The labels of this V1NetworkResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this V1NetworkResponse.

        free labels that you associate with this network.  # noqa: E501

        :param labels: The labels of this V1NetworkResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this V1NetworkResponse.  # noqa: E501

        a readable name for this entity  # noqa: E501

        :return: The name of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1NetworkResponse.

        a readable name for this entity  # noqa: E501

        :param name: The name of this V1NetworkResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def nat(self):
        """Gets the nat of this V1NetworkResponse.  # noqa: E501

        if set to true, packets leaving this network get masqueraded behind interface ip  # noqa: E501

        :return: The nat of this V1NetworkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._nat

    @nat.setter
    def nat(self, nat):
        """Sets the nat of this V1NetworkResponse.

        if set to true, packets leaving this network get masqueraded behind interface ip  # noqa: E501

        :param nat: The nat of this V1NetworkResponse.  # noqa: E501
        :type: bool
        """
        if nat is None:
            raise ValueError("Invalid value for `nat`, must not be `None`")  # noqa: E501

        self._nat = nat

    @property
    def parentnetworkid(self):
        """Gets the parentnetworkid of this V1NetworkResponse.  # noqa: E501

        the id of the parent network  # noqa: E501

        :return: The parentnetworkid of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._parentnetworkid

    @parentnetworkid.setter
    def parentnetworkid(self, parentnetworkid):
        """Sets the parentnetworkid of this V1NetworkResponse.

        the id of the parent network  # noqa: E501

        :param parentnetworkid: The parentnetworkid of this V1NetworkResponse.  # noqa: E501
        :type: str
        """
        if parentnetworkid is None:
            raise ValueError("Invalid value for `parentnetworkid`, must not be `None`")  # noqa: E501

        self._parentnetworkid = parentnetworkid

    @property
    def partitionid(self):
        """Gets the partitionid of this V1NetworkResponse.  # noqa: E501

        the partition this network belongs to  # noqa: E501

        :return: The partitionid of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._partitionid

    @partitionid.setter
    def partitionid(self, partitionid):
        """Sets the partitionid of this V1NetworkResponse.

        the partition this network belongs to  # noqa: E501

        :param partitionid: The partitionid of this V1NetworkResponse.  # noqa: E501
        :type: str
        """

        self._partitionid = partitionid

    @property
    def prefixes(self):
        """Gets the prefixes of this V1NetworkResponse.  # noqa: E501

        the prefixes of this network  # noqa: E501

        :return: The prefixes of this V1NetworkResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this V1NetworkResponse.

        the prefixes of this network  # noqa: E501

        :param prefixes: The prefixes of this V1NetworkResponse.  # noqa: E501
        :type: list[str]
        """
        if prefixes is None:
            raise ValueError("Invalid value for `prefixes`, must not be `None`")  # noqa: E501

        self._prefixes = prefixes

    @property
    def privatesuper(self):
        """Gets the privatesuper of this V1NetworkResponse.  # noqa: E501

        if set to true, this network will serve as a partition's super network for the internal machine networks,there can only be one privatesuper network per partition  # noqa: E501

        :return: The privatesuper of this V1NetworkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._privatesuper

    @privatesuper.setter
    def privatesuper(self, privatesuper):
        """Sets the privatesuper of this V1NetworkResponse.

        if set to true, this network will serve as a partition's super network for the internal machine networks,there can only be one privatesuper network per partition  # noqa: E501

        :param privatesuper: The privatesuper of this V1NetworkResponse.  # noqa: E501
        :type: bool
        """
        if privatesuper is None:
            raise ValueError("Invalid value for `privatesuper`, must not be `None`")  # noqa: E501

        self._privatesuper = privatesuper

    @property
    def projectid(self):
        """Gets the projectid of this V1NetworkResponse.  # noqa: E501

        the project id this network belongs to, can be empty if globally available  # noqa: E501

        :return: The projectid of this V1NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._projectid

    @projectid.setter
    def projectid(self, projectid):
        """Sets the projectid of this V1NetworkResponse.

        the project id this network belongs to, can be empty if globally available  # noqa: E501

        :param projectid: The projectid of this V1NetworkResponse.  # noqa: E501
        :type: str
        """

        self._projectid = projectid

    @property
    def underlay(self):
        """Gets the underlay of this V1NetworkResponse.  # noqa: E501

        if set to true, this network can be used for underlay communication  # noqa: E501

        :return: The underlay of this V1NetworkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._underlay

    @underlay.setter
    def underlay(self, underlay):
        """Sets the underlay of this V1NetworkResponse.

        if set to true, this network can be used for underlay communication  # noqa: E501

        :param underlay: The underlay of this V1NetworkResponse.  # noqa: E501
        :type: bool
        """
        if underlay is None:
            raise ValueError("Invalid value for `underlay`, must not be `None`")  # noqa: E501

        self._underlay = underlay

    @property
    def usage(self):
        """Gets the usage of this V1NetworkResponse.  # noqa: E501

        usage of ips and prefixes in this network  # noqa: E501

        :return: The usage of this V1NetworkResponse.  # noqa: E501
        :rtype: V1NetworkUsage
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this V1NetworkResponse.

        usage of ips and prefixes in this network  # noqa: E501

        :param usage: The usage of this V1NetworkResponse.  # noqa: E501
        :type: V1NetworkUsage
        """
        if usage is None:
            raise ValueError("Invalid value for `usage`, must not be `None`")  # noqa: E501

        self._usage = usage

    @property
    def vrf(self):
        """Gets the vrf of this V1NetworkResponse.  # noqa: E501

        the vrf this network is associated with  # noqa: E501

        :return: The vrf of this V1NetworkResponse.  # noqa: E501
        :rtype: int
        """
        return self._vrf

    @vrf.setter
    def vrf(self, vrf):
        """Sets the vrf of this V1NetworkResponse.

        the vrf this network is associated with  # noqa: E501

        :param vrf: The vrf of this V1NetworkResponse.  # noqa: E501
        :type: int
        """

        self._vrf = vrf

    @property
    def vrfshared(self):
        """Gets the vrfshared of this V1NetworkResponse.  # noqa: E501

        if set to true, given vrf can be used by multiple networks, which is sometimes useful for network partioning (default: false)  # noqa: E501

        :return: The vrfshared of this V1NetworkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._vrfshared

    @vrfshared.setter
    def vrfshared(self, vrfshared):
        """Sets the vrfshared of this V1NetworkResponse.

        if set to true, given vrf can be used by multiple networks, which is sometimes useful for network partioning (default: false)  # noqa: E501

        :param vrfshared: The vrfshared of this V1NetworkResponse.  # noqa: E501
        :type: bool
        """

        self._vrfshared = vrfshared

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1NetworkResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1NetworkUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'available_ips': 'int',
        'available_prefixes': 'int',
        'used_ips': 'int',
        'used_prefixes': 'int'
    }

    attribute_map = {
        'available_ips': 'available_ips',
        'available_prefixes': 'available_prefixes',
        'used_ips': 'used_ips',
        'used_prefixes': 'used_prefixes'
    }

    def __init__(self, available_ips=None, available_prefixes=None, used_ips=None, used_prefixes=None):  # noqa: E501
        """V1NetworkUsage - a model defined in Swagger"""  # noqa: E501

        self._available_ips = None
        self._available_prefixes = None
        self._used_ips = None
        self._used_prefixes = None
        self.discriminator = None

        self.available_ips = available_ips
        self.available_prefixes = available_prefixes
        self.used_ips = used_ips
        self.used_prefixes = used_prefixes

    @property
    def available_ips(self):
        """Gets the available_ips of this V1NetworkUsage.  # noqa: E501

        the total available IPs  # noqa: E501

        :return: The available_ips of this V1NetworkUsage.  # noqa: E501
        :rtype: int
        """
        return self._available_ips

    @available_ips.setter
    def available_ips(self, available_ips):
        """Sets the available_ips of this V1NetworkUsage.

        the total available IPs  # noqa: E501

        :param available_ips: The available_ips of this V1NetworkUsage.  # noqa: E501
        :type: int
        """
        if available_ips is None:
            raise ValueError("Invalid value for `available_ips`, must not be `None`")  # noqa: E501

        self._available_ips = available_ips

    @property
    def available_prefixes(self):
        """Gets the available_prefixes of this V1NetworkUsage.  # noqa: E501

        the total available Prefixes  # noqa: E501

        :return: The available_prefixes of this V1NetworkUsage.  # noqa: E501
        :rtype: int
        """
        return self._available_prefixes

    @available_prefixes.setter
    def available_prefixes(self, available_prefixes):
        """Sets the available_prefixes of this V1NetworkUsage.

        the total available Prefixes  # noqa: E501

        :param available_prefixes: The available_prefixes of this V1NetworkUsage.  # noqa: E501
        :type: int
        """
        if available_prefixes is None:
            raise ValueError("Invalid value for `available_prefixes`, must not be `None`")  # noqa: E501

        self._available_prefixes = available_prefixes

    @property
    def used_ips(self):
        """Gets the used_ips of this V1NetworkUsage.  # noqa: E501

        the total used IPs  # noqa: E501

        :return: The used_ips of this V1NetworkUsage.  # noqa: E501
        :rtype: int
        """
        return self._used_ips

    @used_ips.setter
    def used_ips(self, used_ips):
        """Sets the used_ips of this V1NetworkUsage.

        the total used IPs  # noqa: E501

        :param used_ips: The used_ips of this V1NetworkUsage.  # noqa: E501
        :type: int
        """
        if used_ips is None:
            raise ValueError("Invalid value for `used_ips`, must not be `None`")  # noqa: E501

        self._used_ips = used_ips

    @property
    def used_prefixes(self):
        """Gets the used_prefixes of this V1NetworkUsage.  # noqa: E501

        the total used Prefixes  # noqa: E501

        :return: The used_prefixes of this V1NetworkUsage.  # noqa: E501
        :rtype: int
        """
        return self._used_prefixes

    @used_prefixes.setter
    def used_prefixes(self, used_prefixes):
        """Sets the used_prefixes of this V1NetworkUsage.

        the total used Prefixes  # noqa: E501

        :param used_prefixes: The used_prefixes of this V1NetworkUsage.  # noqa: E501
        :type: int
        """
        if used_prefixes is None:
            raise ValueError("Invalid value for `used_prefixes`, must not be `None`")  # noqa: E501

        self._used_prefixes = used_prefixes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1NetworkUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1SizeConstraintMatchingLog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'constraint': 'V1SizeConstraint',
        'log': 'str',
        'match': 'bool'
    }

    attribute_map = {
        'constraint': 'constraint',
        'log': 'log',
        'match': 'match'
    }

    def __init__(self, constraint=None, log=None, match=None):  # noqa: E501
        """V1SizeConstraintMatchingLog - a model defined in Swagger"""  # noqa: E501

        self._constraint = None
        self._log = None
        self._match = None
        self.discriminator = None

        self.constraint = constraint
        self.log = log
        self.match = match

    @property
    def constraint(self):
        """Gets the constraint of this V1SizeConstraintMatchingLog.  # noqa: E501

        the size constraint to which this log relates to  # noqa: E501

        :return: The constraint of this V1SizeConstraintMatchingLog.  # noqa: E501
        :rtype: V1SizeConstraint
        """
        return self._constraint

    @constraint.setter
    def constraint(self, constraint):
        """Sets the constraint of this V1SizeConstraintMatchingLog.

        the size constraint to which this log relates to  # noqa: E501

        :param constraint: The constraint of this V1SizeConstraintMatchingLog.  # noqa: E501
        :type: V1SizeConstraint
        """
        if constraint is None:
            raise ValueError("Invalid value for `constraint`, must not be `None`")  # noqa: E501

        self._constraint = constraint

    @property
    def log(self):
        """Gets the log of this V1SizeConstraintMatchingLog.  # noqa: E501

        a string represention of the matching condition  # noqa: E501

        :return: The log of this V1SizeConstraintMatchingLog.  # noqa: E501
        :rtype: str
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this V1SizeConstraintMatchingLog.

        a string represention of the matching condition  # noqa: E501

        :param log: The log of this V1SizeConstraintMatchingLog.  # noqa: E501
        :type: str
        """
        if log is None:
            raise ValueError("Invalid value for `log`, must not be `None`")  # noqa: E501

        self._log = log

    @property
    def match(self):
        """Gets the match of this V1SizeConstraintMatchingLog.  # noqa: E501

        indicates whether the constraint matched or not  # noqa: E501

        :return: The match of this V1SizeConstraintMatchingLog.  # noqa: E501
        :rtype: bool
        """
        return self._match

    @match.setter
    def match(self, match):
        """Sets the match of this V1SizeConstraintMatchingLog.

        indicates whether the constraint matched or not  # noqa: E501

        :param match: The match of this V1SizeConstraintMatchingLog.  # noqa: E501
        :type: bool
        """
        if match is None:
            raise ValueError("Invalid value for `match`, must not be `None`")  # noqa: E501

        self._match = match

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1SizeConstraintMatchingLog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SizeConstraintMatchingLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1FirewallFindRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation_hostname': 'str',
        'allocation_image_id': 'str',
        'allocation_name': 'str',
        'allocation_project': 'str',
        'allocation_succeeded': 'bool',
        'disk_names': 'list[str]',
        'disk_sizes': 'list[int]',
        'fru_board_mfg': 'str',
        'fru_board_mfg_serial': 'str',
        'fru_board_part_number': 'str',
        'fru_chassis_part_number': 'str',
        'fru_chassis_part_serial': 'str',
        'fru_product_manufacturer': 'str',
        'fru_product_part_number': 'str',
        'fru_product_serial': 'str',
        'hardware_cpu_cores': 'int',
        'hardware_memory': 'int',
        'id': 'str',
        'ipmi_address': 'str',
        'ipmi_interface': 'str',
        'ipmi_mac_address': 'str',
        'ipmi_user': 'str',
        'liveliness': 'str',
        'name': 'str',
        'network_asns': 'list[int]',
        'network_destination_prefixes': 'list[str]',
        'network_ids': 'list[str]',
        'network_ips': 'list[str]',
        'network_nat': 'bool',
        'network_prefixes': 'list[str]',
        'network_private': 'bool',
        'network_underlay': 'bool',
        'network_vrfs': 'list[int]',
        'nics_mac_addresses': 'list[str]',
        'nics_names': 'list[str]',
        'nics_neighbor_mac_addresses': 'list[str]',
        'nics_neighbor_names': 'list[str]',
        'nics_neighbor_vrfs': 'list[str]',
        'nics_vrfs': 'list[str]',
        'partition_id': 'str',
        'rackid': 'str',
        'sizeid': 'str',
        'state_value': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'allocation_hostname': 'allocation_hostname',
        'allocation_image_id': 'allocation_image_id',
        'allocation_name': 'allocation_name',
        'allocation_project': 'allocation_project',
        'allocation_succeeded': 'allocation_succeeded',
        'disk_names': 'disk_names',
        'disk_sizes': 'disk_sizes',
        'fru_board_mfg': 'fru_board_mfg',
        'fru_board_mfg_serial': 'fru_board_mfg_serial',
        'fru_board_part_number': 'fru_board_part_number',
        'fru_chassis_part_number': 'fru_chassis_part_number',
        'fru_chassis_part_serial': 'fru_chassis_part_serial',
        'fru_product_manufacturer': 'fru_product_manufacturer',
        'fru_product_part_number': 'fru_product_part_number',
        'fru_product_serial': 'fru_product_serial',
        'hardware_cpu_cores': 'hardware_cpu_cores',
        'hardware_memory': 'hardware_memory',
        'id': 'id',
        'ipmi_address': 'ipmi_address',
        'ipmi_interface': 'ipmi_interface',
        'ipmi_mac_address': 'ipmi_mac_address',
        'ipmi_user': 'ipmi_user',
        'liveliness': 'liveliness',
        'name': 'name',
        'network_asns': 'network_asns',
        'network_destination_prefixes': 'network_destination_prefixes',
        'network_ids': 'network_ids',
        'network_ips': 'network_ips',
        'network_nat': 'network_nat',
        'network_prefixes': 'network_prefixes',
        'network_private': 'network_private',
        'network_underlay': 'network_underlay',
        'network_vrfs': 'network_vrfs',
        'nics_mac_addresses': 'nics_mac_addresses',
        'nics_names': 'nics_names',
        'nics_neighbor_mac_addresses': 'nics_neighbor_mac_addresses',
        'nics_neighbor_names': 'nics_neighbor_names',
        'nics_neighbor_vrfs': 'nics_neighbor_vrfs',
        'nics_vrfs': 'nics_vrfs',
        'partition_id': 'partition_id',
        'rackid': 'rackid',
        'sizeid': 'sizeid',
        'state_value': 'state_value',
        'tags': 'tags'
    }

    def __init__(self, allocation_hostname=None, allocation_image_id=None, allocation_name=None, allocation_project=None, allocation_succeeded=None, disk_names=None, disk_sizes=None, fru_board_mfg=None, fru_board_mfg_serial=None, fru_board_part_number=None, fru_chassis_part_number=None, fru_chassis_part_serial=None, fru_product_manufacturer=None, fru_product_part_number=None, fru_product_serial=None, hardware_cpu_cores=None, hardware_memory=None, id=None, ipmi_address=None, ipmi_interface=None, ipmi_mac_address=None, ipmi_user=None, liveliness=None, name=None, network_asns=None, network_destination_prefixes=None, network_ids=None, network_ips=None, network_nat=None, network_prefixes=None, network_private=None, network_underlay=None, network_vrfs=None, nics_mac_addresses=None, nics_names=None, nics_neighbor_mac_addresses=None, nics_neighbor_names=None, nics_neighbor_vrfs=None, nics_vrfs=None, partition_id=None, rackid=None, sizeid=None, state_value=None, tags=None):  # noqa: E501
        """V1FirewallFindRequest - a model defined in Swagger"""  # noqa: E501

        self._allocation_hostname = None
        self._allocation_image_id = None
        self._allocation_name = None
        self._allocation_project = None
        self._allocation_succeeded = None
        self._disk_names = None
        self._disk_sizes = None
        self._fru_board_mfg = None
        self._fru_board_mfg_serial = None
        self._fru_board_part_number = None
        self._fru_chassis_part_number = None
        self._fru_chassis_part_serial = None
        self._fru_product_manufacturer = None
        self._fru_product_part_number = None
        self._fru_product_serial = None
        self._hardware_cpu_cores = None
        self._hardware_memory = None
        self._id = None
        self._ipmi_address = None
        self._ipmi_interface = None
        self._ipmi_mac_address = None
        self._ipmi_user = None
        self._liveliness = None
        self._name = None
        self._network_asns = None
        self._network_destination_prefixes = None
        self._network_ids = None
        self._network_ips = None
        self._network_nat = None
        self._network_prefixes = None
        self._network_private = None
        self._network_underlay = None
        self._network_vrfs = None
        self._nics_mac_addresses = None
        self._nics_names = None
        self._nics_neighbor_mac_addresses = None
        self._nics_neighbor_names = None
        self._nics_neighbor_vrfs = None
        self._nics_vrfs = None
        self._partition_id = None
        self._rackid = None
        self._sizeid = None
        self._state_value = None
        self._tags = None
        self.discriminator = None

        if allocation_hostname is not None:
            self.allocation_hostname = allocation_hostname
        if allocation_image_id is not None:
            self.allocation_image_id = allocation_image_id
        if allocation_name is not None:
            self.allocation_name = allocation_name
        if allocation_project is not None:
            self.allocation_project = allocation_project
        if allocation_succeeded is not None:
            self.allocation_succeeded = allocation_succeeded
        if disk_names is not None:
            self.disk_names = disk_names
        if disk_sizes is not None:
            self.disk_sizes = disk_sizes
        if fru_board_mfg is not None:
            self.fru_board_mfg = fru_board_mfg
        if fru_board_mfg_serial is not None:
            self.fru_board_mfg_serial = fru_board_mfg_serial
        if fru_board_part_number is not None:
            self.fru_board_part_number = fru_board_part_number
        if fru_chassis_part_number is not None:
            self.fru_chassis_part_number = fru_chassis_part_number
        if fru_chassis_part_serial is not None:
            self.fru_chassis_part_serial = fru_chassis_part_serial
        if fru_product_manufacturer is not None:
            self.fru_product_manufacturer = fru_product_manufacturer
        if fru_product_part_number is not None:
            self.fru_product_part_number = fru_product_part_number
        if fru_product_serial is not None:
            self.fru_product_serial = fru_product_serial
        if hardware_cpu_cores is not None:
            self.hardware_cpu_cores = hardware_cpu_cores
        if hardware_memory is not None:
            self.hardware_memory = hardware_memory
        if id is not None:
            self.id = id
        if ipmi_address is not None:
            self.ipmi_address = ipmi_address
        if ipmi_interface is not None:
            self.ipmi_interface = ipmi_interface
        if ipmi_mac_address is not None:
            self.ipmi_mac_address = ipmi_mac_address
        if ipmi_user is not None:
            self.ipmi_user = ipmi_user
        if liveliness is not None:
            self.liveliness = liveliness
        if name is not None:
            self.name = name
        if network_asns is not None:
            self.network_asns = network_asns
        if network_destination_prefixes is not None:
            self.network_destination_prefixes = network_destination_prefixes
        if network_ids is not None:
            self.network_ids = network_ids
        if network_ips is not None:
            self.network_ips = network_ips
        if network_nat is not None:
            self.network_nat = network_nat
        if network_prefixes is not None:
            self.network_prefixes = network_prefixes
        if network_private is not None:
            self.network_private = network_private
        if network_underlay is not None:
            self.network_underlay = network_underlay
        if network_vrfs is not None:
            self.network_vrfs = network_vrfs
        if nics_mac_addresses is not None:
            self.nics_mac_addresses = nics_mac_addresses
        if nics_names is not None:
            self.nics_names = nics_names
        if nics_neighbor_mac_addresses is not None:
            self.nics_neighbor_mac_addresses = nics_neighbor_mac_addresses
        if nics_neighbor_names is not None:
            self.nics_neighbor_names = nics_neighbor_names
        if nics_neighbor_vrfs is not None:
            self.nics_neighbor_vrfs = nics_neighbor_vrfs
        if nics_vrfs is not None:
            self.nics_vrfs = nics_vrfs
        if partition_id is not None:
            self.partition_id = partition_id
        if rackid is not None:
            self.rackid = rackid
        if sizeid is not None:
            self.sizeid = sizeid
        if state_value is not None:
            self.state_value = state_value
        if tags is not None:
            self.tags = tags

    @property
    def allocation_hostname(self):
        """Gets the allocation_hostname of this V1FirewallFindRequest.  # noqa: E501


        :return: The allocation_hostname of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_hostname

    @allocation_hostname.setter
    def allocation_hostname(self, allocation_hostname):
        """Sets the allocation_hostname of this V1FirewallFindRequest.


        :param allocation_hostname: The allocation_hostname of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._allocation_hostname = allocation_hostname

    @property
    def allocation_image_id(self):
        """Gets the allocation_image_id of this V1FirewallFindRequest.  # noqa: E501


        :return: The allocation_image_id of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_image_id

    @allocation_image_id.setter
    def allocation_image_id(self, allocation_image_id):
        """Sets the allocation_image_id of this V1FirewallFindRequest.


        :param allocation_image_id: The allocation_image_id of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._allocation_image_id = allocation_image_id

    @property
    def allocation_name(self):
        """Gets the allocation_name of this V1FirewallFindRequest.  # noqa: E501


        :return: The allocation_name of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_name

    @allocation_name.setter
    def allocation_name(self, allocation_name):
        """Sets the allocation_name of this V1FirewallFindRequest.


        :param allocation_name: The allocation_name of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._allocation_name = allocation_name

    @property
    def allocation_project(self):
        """Gets the allocation_project of this V1FirewallFindRequest.  # noqa: E501


        :return: The allocation_project of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_project

    @allocation_project.setter
    def allocation_project(self, allocation_project):
        """Sets the allocation_project of this V1FirewallFindRequest.


        :param allocation_project: The allocation_project of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._allocation_project = allocation_project

    @property
    def allocation_succeeded(self):
        """Gets the allocation_succeeded of this V1FirewallFindRequest.  # noqa: E501


        :return: The allocation_succeeded of this V1FirewallFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allocation_succeeded

    @allocation_succeeded.setter
    def allocation_succeeded(self, allocation_succeeded):
        """Sets the allocation_succeeded of this V1FirewallFindRequest.


        :param allocation_succeeded: The allocation_succeeded of this V1FirewallFindRequest.  # noqa: E501
        :type: bool
        """

        self._allocation_succeeded = allocation_succeeded

    @property
    def disk_names(self):
        """Gets the disk_names of this V1FirewallFindRequest.  # noqa: E501


        :return: The disk_names of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._disk_names

    @disk_names.setter
    def disk_names(self, disk_names):
        """Sets the disk_names of this V1FirewallFindRequest.


        :param disk_names: The disk_names of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._disk_names = disk_names

    @property
    def disk_sizes(self):
        """Gets the disk_sizes of this V1FirewallFindRequest.  # noqa: E501


        :return: The disk_sizes of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._disk_sizes

    @disk_sizes.setter
    def disk_sizes(self, disk_sizes):
        """Sets the disk_sizes of this V1FirewallFindRequest.


        :param disk_sizes: The disk_sizes of this V1FirewallFindRequest.  # noqa: E501
        :type: list[int]
        """

        self._disk_sizes = disk_sizes

    @property
    def fru_board_mfg(self):
        """Gets the fru_board_mfg of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_board_mfg of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_board_mfg

    @fru_board_mfg.setter
    def fru_board_mfg(self, fru_board_mfg):
        """Sets the fru_board_mfg of this V1FirewallFindRequest.


        :param fru_board_mfg: The fru_board_mfg of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_board_mfg = fru_board_mfg

    @property
    def fru_board_mfg_serial(self):
        """Gets the fru_board_mfg_serial of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_board_mfg_serial of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_board_mfg_serial

    @fru_board_mfg_serial.setter
    def fru_board_mfg_serial(self, fru_board_mfg_serial):
        """Sets the fru_board_mfg_serial of this V1FirewallFindRequest.


        :param fru_board_mfg_serial: The fru_board_mfg_serial of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_board_mfg_serial = fru_board_mfg_serial

    @property
    def fru_board_part_number(self):
        """Gets the fru_board_part_number of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_board_part_number of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_board_part_number

    @fru_board_part_number.setter
    def fru_board_part_number(self, fru_board_part_number):
        """Sets the fru_board_part_number of this V1FirewallFindRequest.


        :param fru_board_part_number: The fru_board_part_number of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_board_part_number = fru_board_part_number

    @property
    def fru_chassis_part_number(self):
        """Gets the fru_chassis_part_number of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_chassis_part_number of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_chassis_part_number

    @fru_chassis_part_number.setter
    def fru_chassis_part_number(self, fru_chassis_part_number):
        """Sets the fru_chassis_part_number of this V1FirewallFindRequest.


        :param fru_chassis_part_number: The fru_chassis_part_number of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_chassis_part_number = fru_chassis_part_number

    @property
    def fru_chassis_part_serial(self):
        """Gets the fru_chassis_part_serial of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_chassis_part_serial of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_chassis_part_serial

    @fru_chassis_part_serial.setter
    def fru_chassis_part_serial(self, fru_chassis_part_serial):
        """Sets the fru_chassis_part_serial of this V1FirewallFindRequest.


        :param fru_chassis_part_serial: The fru_chassis_part_serial of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_chassis_part_serial = fru_chassis_part_serial

    @property
    def fru_product_manufacturer(self):
        """Gets the fru_product_manufacturer of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_product_manufacturer of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_product_manufacturer

    @fru_product_manufacturer.setter
    def fru_product_manufacturer(self, fru_product_manufacturer):
        """Sets the fru_product_manufacturer of this V1FirewallFindRequest.


        :param fru_product_manufacturer: The fru_product_manufacturer of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_product_manufacturer = fru_product_manufacturer

    @property
    def fru_product_part_number(self):
        """Gets the fru_product_part_number of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_product_part_number of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_product_part_number

    @fru_product_part_number.setter
    def fru_product_part_number(self, fru_product_part_number):
        """Sets the fru_product_part_number of this V1FirewallFindRequest.


        :param fru_product_part_number: The fru_product_part_number of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_product_part_number = fru_product_part_number

    @property
    def fru_product_serial(self):
        """Gets the fru_product_serial of this V1FirewallFindRequest.  # noqa: E501


        :return: The fru_product_serial of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._fru_product_serial

    @fru_product_serial.setter
    def fru_product_serial(self, fru_product_serial):
        """Sets the fru_product_serial of this V1FirewallFindRequest.


        :param fru_product_serial: The fru_product_serial of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._fru_product_serial = fru_product_serial

    @property
    def hardware_cpu_cores(self):
        """Gets the hardware_cpu_cores of this V1FirewallFindRequest.  # noqa: E501


        :return: The hardware_cpu_cores of this V1FirewallFindRequest.  # noqa: E501
        :rtype: int
        """
        return self._hardware_cpu_cores

    @hardware_cpu_cores.setter
    def hardware_cpu_cores(self, hardware_cpu_cores):
        """Sets the hardware_cpu_cores of this V1FirewallFindRequest.


        :param hardware_cpu_cores: The hardware_cpu_cores of this V1FirewallFindRequest.  # noqa: E501
        :type: int
        """

        self._hardware_cpu_cores = hardware_cpu_cores

    @property
    def hardware_memory(self):
        """Gets the hardware_memory of this V1FirewallFindRequest.  # noqa: E501


        :return: The hardware_memory of this V1FirewallFindRequest.  # noqa: E501
        :rtype: int
        """
        return self._hardware_memory

    @hardware_memory.setter
    def hardware_memory(self, hardware_memory):
        """Sets the hardware_memory of this V1FirewallFindRequest.


        :param hardware_memory: The hardware_memory of this V1FirewallFindRequest.  # noqa: E501
        :type: int
        """

        self._hardware_memory = hardware_memory

    @property
    def id(self):
        """Gets the id of this V1FirewallFindRequest.  # noqa: E501


        :return: The id of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1FirewallFindRequest.


        :param id: The id of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ipmi_address(self):
        """Gets the ipmi_address of this V1FirewallFindRequest.  # noqa: E501


        :return: The ipmi_address of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipmi_address

    @ipmi_address.setter
    def ipmi_address(self, ipmi_address):
        """Sets the ipmi_address of this V1FirewallFindRequest.


        :param ipmi_address: The ipmi_address of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._ipmi_address = ipmi_address

    @property
    def ipmi_interface(self):
        """Gets the ipmi_interface of this V1FirewallFindRequest.  # noqa: E501


        :return: The ipmi_interface of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipmi_interface

    @ipmi_interface.setter
    def ipmi_interface(self, ipmi_interface):
        """Sets the ipmi_interface of this V1FirewallFindRequest.


        :param ipmi_interface: The ipmi_interface of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._ipmi_interface = ipmi_interface

    @property
    def ipmi_mac_address(self):
        """Gets the ipmi_mac_address of this V1FirewallFindRequest.  # noqa: E501


        :return: The ipmi_mac_address of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipmi_mac_address

    @ipmi_mac_address.setter
    def ipmi_mac_address(self, ipmi_mac_address):
        """Sets the ipmi_mac_address of this V1FirewallFindRequest.


        :param ipmi_mac_address: The ipmi_mac_address of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._ipmi_mac_address = ipmi_mac_address

    @property
    def ipmi_user(self):
        """Gets the ipmi_user of this V1FirewallFindRequest.  # noqa: E501


        :return: The ipmi_user of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipmi_user

    @ipmi_user.setter
    def ipmi_user(self, ipmi_user):
        """Sets the ipmi_user of this V1FirewallFindRequest.


        :param ipmi_user: The ipmi_user of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._ipmi_user = ipmi_user

    @property
    def liveliness(self):
        """Gets the liveliness of this V1FirewallFindRequest.  # noqa: E501


        :return: The liveliness of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._liveliness

    @liveliness.setter
    def liveliness(self, liveliness):
        """Sets the liveliness of this V1FirewallFindRequest.


        :param liveliness: The liveliness of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._liveliness = liveliness

    @property
    def name(self):
        """Gets the name of this V1FirewallFindRequest.  # noqa: E501


        :return: The name of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1FirewallFindRequest.


        :param name: The name of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def network_asns(self):
        """Gets the network_asns of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_asns of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._network_asns

    @network_asns.setter
    def network_asns(self, network_asns):
        """Sets the network_asns of this V1FirewallFindRequest.


        :param network_asns: The network_asns of this V1FirewallFindRequest.  # noqa: E501
        :type: list[int]
        """

        self._network_asns = network_asns

    @property
    def network_destination_prefixes(self):
        """Gets the network_destination_prefixes of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_destination_prefixes of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._network_destination_prefixes

    @network_destination_prefixes.setter
    def network_destination_prefixes(self, network_destination_prefixes):
        """Sets the network_destination_prefixes of this V1FirewallFindRequest.


        :param network_destination_prefixes: The network_destination_prefixes of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._network_destination_prefixes = network_destination_prefixes

    @property
    def network_ids(self):
        """Gets the network_ids of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_ids of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._network_ids

    @network_ids.setter
    def network_ids(self, network_ids):
        """Sets the network_ids of this V1FirewallFindRequest.


        :param network_ids: The network_ids of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._network_ids = network_ids

    @property
    def network_ips(self):
        """Gets the network_ips of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_ips of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._network_ips

    @network_ips.setter
    def network_ips(self, network_ips):
        """Sets the network_ips of this V1FirewallFindRequest.


        :param network_ips: The network_ips of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._network_ips = network_ips

    @property
    def network_nat(self):
        """Gets the network_nat of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_nat of this V1FirewallFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._network_nat

    @network_nat.setter
    def network_nat(self, network_nat):
        """Sets the network_nat of this V1FirewallFindRequest.


        :param network_nat: The network_nat of this V1FirewallFindRequest.  # noqa: E501
        :type: bool
        """

        self._network_nat = network_nat

    @property
    def network_prefixes(self):
        """Gets the network_prefixes of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_prefixes of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._network_prefixes

    @network_prefixes.setter
    def network_prefixes(self, network_prefixes):
        """Sets the network_prefixes of this V1FirewallFindRequest.


        :param network_prefixes: The network_prefixes of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._network_prefixes = network_prefixes

    @property
    def network_private(self):
        """Gets the network_private of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_private of this V1FirewallFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._network_private

    @network_private.setter
    def network_private(self, network_private):
        """Sets the network_private of this V1FirewallFindRequest.


        :param network_private: The network_private of this V1FirewallFindRequest.  # noqa: E501
        :type: bool
        """

        self._network_private = network_private

    @property
    def network_underlay(self):
        """Gets the network_underlay of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_underlay of this V1FirewallFindRequest.  # noqa: E501
        :rtype: bool
        """
        return self._network_underlay

    @network_underlay.setter
    def network_underlay(self, network_underlay):
        """Sets the network_underlay of this V1FirewallFindRequest.


        :param network_underlay: The network_underlay of this V1FirewallFindRequest.  # noqa: E501
        :type: bool
        """

        self._network_underlay = network_underlay

    @property
    def network_vrfs(self):
        """Gets the network_vrfs of this V1FirewallFindRequest.  # noqa: E501


        :return: The network_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._network_vrfs

    @network_vrfs.setter
    def network_vrfs(self, network_vrfs):
        """Sets the network_vrfs of this V1FirewallFindRequest.


        :param network_vrfs: The network_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :type: list[int]
        """

        self._network_vrfs = network_vrfs

    @property
    def nics_mac_addresses(self):
        """Gets the nics_mac_addresses of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_mac_addresses of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_mac_addresses

    @nics_mac_addresses.setter
    def nics_mac_addresses(self, nics_mac_addresses):
        """Sets the nics_mac_addresses of this V1FirewallFindRequest.


        :param nics_mac_addresses: The nics_mac_addresses of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_mac_addresses = nics_mac_addresses

    @property
    def nics_names(self):
        """Gets the nics_names of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_names of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_names

    @nics_names.setter
    def nics_names(self, nics_names):
        """Sets the nics_names of this V1FirewallFindRequest.


        :param nics_names: The nics_names of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_names = nics_names

    @property
    def nics_neighbor_mac_addresses(self):
        """Gets the nics_neighbor_mac_addresses of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_neighbor_mac_addresses of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_neighbor_mac_addresses

    @nics_neighbor_mac_addresses.setter
    def nics_neighbor_mac_addresses(self, nics_neighbor_mac_addresses):
        """Sets the nics_neighbor_mac_addresses of this V1FirewallFindRequest.


        :param nics_neighbor_mac_addresses: The nics_neighbor_mac_addresses of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_neighbor_mac_addresses = nics_neighbor_mac_addresses

    @property
    def nics_neighbor_names(self):
        """Gets the nics_neighbor_names of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_neighbor_names of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_neighbor_names

    @nics_neighbor_names.setter
    def nics_neighbor_names(self, nics_neighbor_names):
        """Sets the nics_neighbor_names of this V1FirewallFindRequest.


        :param nics_neighbor_names: The nics_neighbor_names of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_neighbor_names = nics_neighbor_names

    @property
    def nics_neighbor_vrfs(self):
        """Gets the nics_neighbor_vrfs of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_neighbor_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_neighbor_vrfs

    @nics_neighbor_vrfs.setter
    def nics_neighbor_vrfs(self, nics_neighbor_vrfs):
        """Sets the nics_neighbor_vrfs of this V1FirewallFindRequest.


        :param nics_neighbor_vrfs: The nics_neighbor_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_neighbor_vrfs = nics_neighbor_vrfs

    @property
    def nics_vrfs(self):
        """Gets the nics_vrfs of this V1FirewallFindRequest.  # noqa: E501


        :return: The nics_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._nics_vrfs

    @nics_vrfs.setter
    def nics_vrfs(self, nics_vrfs):
        """Sets the nics_vrfs of this V1FirewallFindRequest.


        :param nics_vrfs: The nics_vrfs of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._nics_vrfs = nics_vrfs

    @property
    def partition_id(self):
        """Gets the partition_id of this V1FirewallFindRequest.  # noqa: E501


        :return: The partition_id of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._partition_id

    @partition_id.setter
    def partition_id(self, partition_id):
        """Sets the partition_id of this V1FirewallFindRequest.


        :param partition_id: The partition_id of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._partition_id = partition_id

    @property
    def rackid(self):
        """Gets the rackid of this V1FirewallFindRequest.  # noqa: E501


        :return: The rackid of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._rackid

    @rackid.setter
    def rackid(self, rackid):
        """Sets the rackid of this V1FirewallFindRequest.


        :param rackid: The rackid of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._rackid = rackid

    @property
    def sizeid(self):
        """Gets the sizeid of this V1FirewallFindRequest.  # noqa: E501


        :return: The sizeid of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._sizeid

    @sizeid.setter
    def sizeid(self, sizeid):
        """Sets the sizeid of this V1FirewallFindRequest.


        :param sizeid: The sizeid of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._sizeid = sizeid

    @property
    def state_value(self):
        """Gets the state_value of this V1FirewallFindRequest.  # noqa: E501


        :return: The state_value of this V1FirewallFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._state_value

    @state_value.setter
    def state_value(self, state_value):
        """Sets the state_value of this V1FirewallFindRequest.


        :param state_value: The state_value of this V1FirewallFindRequest.  # noqa: E501
        :type: str
        """

        self._state_value = state_value

    @property
    def tags(self):
        """Gets the tags of this V1FirewallFindRequest.  # noqa: E501


        :return: The tags of this V1FirewallFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1FirewallFindRequest.


        :param tags: The tags of this V1FirewallFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1FirewallFindRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1FirewallFindRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.partition_api import PartitionApi  # noqa: E501
from metal_python.rest import ApiException


class TestPartitionApi(unittest.TestCase):
    """PartitionApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.partition_api.PartitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_partition(self):
        """Test case for create_partition

        create a Partition. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_partition(self):
        """Test case for delete_partition

        deletes a Partition and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_partition(self):
        """Test case for find_partition

        get Partition by id  # noqa: E501
        """
        pass

    def test_list_partitions(self):
        """Test case for list_partitions

        get all Partitions  # noqa: E501
        """
        pass

    def test_partition_capacity(self):
        """Test case for partition_capacity

        get Partition capacity  # noqa: E501
        """
        pass

    def test_update_partition(self):
        """Test case for update_partition

        updates a Partition. if the Partition was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.project_api import ProjectApi  # noqa: E501
from metal_python.rest import ApiException


class TestProjectApi(unittest.TestCase):
    """ProjectApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.project_api.ProjectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_project(self):
        """Test case for create_project

        create a project. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        deletes a project and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_project(self):
        """Test case for find_project

        get project by id  # noqa: E501
        """
        pass

    def test_find_projects(self):
        """Test case for find_projects

        get all projects that match given properties  # noqa: E501
        """
        pass

    def test_list_projects(self):
        """Test case for list_projects

        get all projects  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        update a project. optimistic lock error can occur.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1QuotaSet(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster': 'V1Quota',
        'ip': 'V1Quota',
        'machine': 'V1Quota',
        'project': 'V1Quota'
    }

    attribute_map = {
        'cluster': 'cluster',
        'ip': 'ip',
        'machine': 'machine',
        'project': 'project'
    }

    def __init__(self, cluster=None, ip=None, machine=None, project=None):  # noqa: E501
        """V1QuotaSet - a model defined in Swagger"""  # noqa: E501

        self._cluster = None
        self._ip = None
        self._machine = None
        self._project = None
        self.discriminator = None

        if cluster is not None:
            self.cluster = cluster
        if ip is not None:
            self.ip = ip
        if machine is not None:
            self.machine = machine
        if project is not None:
            self.project = project

    @property
    def cluster(self):
        """Gets the cluster of this V1QuotaSet.  # noqa: E501


        :return: The cluster of this V1QuotaSet.  # noqa: E501
        :rtype: V1Quota
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this V1QuotaSet.


        :param cluster: The cluster of this V1QuotaSet.  # noqa: E501
        :type: V1Quota
        """

        self._cluster = cluster

    @property
    def ip(self):
        """Gets the ip of this V1QuotaSet.  # noqa: E501


        :return: The ip of this V1QuotaSet.  # noqa: E501
        :rtype: V1Quota
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this V1QuotaSet.


        :param ip: The ip of this V1QuotaSet.  # noqa: E501
        :type: V1Quota
        """

        self._ip = ip

    @property
    def machine(self):
        """Gets the machine of this V1QuotaSet.  # noqa: E501


        :return: The machine of this V1QuotaSet.  # noqa: E501
        :rtype: V1Quota
        """
        return self._machine

    @machine.setter
    def machine(self, machine):
        """Sets the machine of this V1QuotaSet.


        :param machine: The machine of this V1QuotaSet.  # noqa: E501
        :type: V1Quota
        """

        self._machine = machine

    @property
    def project(self):
        """Gets the project of this V1QuotaSet.  # noqa: E501


        :return: The project of this V1QuotaSet.  # noqa: E501
        :rtype: V1Quota
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this V1QuotaSet.


        :param project: The project of this V1QuotaSet.  # noqa: E501
        :type: V1Quota
        """

        self._project = project

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1QuotaSet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1QuotaSet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1ServerCapacity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocated': 'int',
        'faulty': 'int',
        'free': 'int',
        'other': 'int',
        'size': 'str',
        'total': 'int'
    }

    attribute_map = {
        'allocated': 'allocated',
        'faulty': 'faulty',
        'free': 'free',
        'other': 'other',
        'size': 'size',
        'total': 'total'
    }

    def __init__(self, allocated=None, faulty=None, free=None, other=None, size=None, total=None):  # noqa: E501
        """V1ServerCapacity - a model defined in Swagger"""  # noqa: E501

        self._allocated = None
        self._faulty = None
        self._free = None
        self._other = None
        self._size = None
        self._total = None
        self.discriminator = None

        self.allocated = allocated
        self.faulty = faulty
        self.free = free
        self.other = other
        self.size = size
        self.total = total

    @property
    def allocated(self):
        """Gets the allocated of this V1ServerCapacity.  # noqa: E501

        allocated servers with this size  # noqa: E501

        :return: The allocated of this V1ServerCapacity.  # noqa: E501
        :rtype: int
        """
        return self._allocated

    @allocated.setter
    def allocated(self, allocated):
        """Sets the allocated of this V1ServerCapacity.

        allocated servers with this size  # noqa: E501

        :param allocated: The allocated of this V1ServerCapacity.  # noqa: E501
        :type: int
        """
        if allocated is None:
            raise ValueError("Invalid value for `allocated`, must not be `None`")  # noqa: E501

        self._allocated = allocated

    @property
    def faulty(self):
        """Gets the faulty of this V1ServerCapacity.  # noqa: E501

        servers with issues with this size  # noqa: E501

        :return: The faulty of this V1ServerCapacity.  # noqa: E501
        :rtype: int
        """
        return self._faulty

    @faulty.setter
    def faulty(self, faulty):
        """Sets the faulty of this V1ServerCapacity.

        servers with issues with this size  # noqa: E501

        :param faulty: The faulty of this V1ServerCapacity.  # noqa: E501
        :type: int
        """
        if faulty is None:
            raise ValueError("Invalid value for `faulty`, must not be `None`")  # noqa: E501

        self._faulty = faulty

    @property
    def free(self):
        """Gets the free of this V1ServerCapacity.  # noqa: E501

        free servers with this size  # noqa: E501

        :return: The free of this V1ServerCapacity.  # noqa: E501
        :rtype: int
        """
        return self._free

    @free.setter
    def free(self, free):
        """Sets the free of this V1ServerCapacity.

        free servers with this size  # noqa: E501

        :param free: The free of this V1ServerCapacity.  # noqa: E501
        :type: int
        """
        if free is None:
            raise ValueError("Invalid value for `free`, must not be `None`")  # noqa: E501

        self._free = free

    @property
    def other(self):
        """Gets the other of this V1ServerCapacity.  # noqa: E501

        servers neither free, allocated or faulty with this size  # noqa: E501

        :return: The other of this V1ServerCapacity.  # noqa: E501
        :rtype: int
        """
        return self._other

    @other.setter
    def other(self, other):
        """Sets the other of this V1ServerCapacity.

        servers neither free, allocated or faulty with this size  # noqa: E501

        :param other: The other of this V1ServerCapacity.  # noqa: E501
        :type: int
        """
        if other is None:
            raise ValueError("Invalid value for `other`, must not be `None`")  # noqa: E501

        self._other = other

    @property
    def size(self):
        """Gets the size of this V1ServerCapacity.  # noqa: E501

        the size of the server  # noqa: E501

        :return: The size of this V1ServerCapacity.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1ServerCapacity.

        the size of the server  # noqa: E501

        :param size: The size of this V1ServerCapacity.  # noqa: E501
        :type: str
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def total(self):
        """Gets the total of this V1ServerCapacity.  # noqa: E501

        total amount of servers with this size  # noqa: E501

        :return: The total of this V1ServerCapacity.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this V1ServerCapacity.

        total amount of servers with this size  # noqa: E501

        :param total: The total of this V1ServerCapacity.  # noqa: E501
        :type: int
        """
        if total is None:
            raise ValueError("Invalid value for `total`, must not be `None`")  # noqa: E501

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ServerCapacity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ServerCapacity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1BootInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bootloaderid': 'str',
        'cmdline': 'str',
        'image_id': 'str',
        'initrd': 'str',
        'kernel': 'str',
        'os_partition': 'str',
        'primary_disk': 'str'
    }

    attribute_map = {
        'bootloaderid': 'bootloaderid',
        'cmdline': 'cmdline',
        'image_id': 'image_id',
        'initrd': 'initrd',
        'kernel': 'kernel',
        'os_partition': 'os_partition',
        'primary_disk': 'primary_disk'
    }

    def __init__(self, bootloaderid=None, cmdline=None, image_id=None, initrd=None, kernel=None, os_partition=None, primary_disk=None):  # noqa: E501
        """V1BootInfo - a model defined in Swagger"""  # noqa: E501

        self._bootloaderid = None
        self._cmdline = None
        self._image_id = None
        self._initrd = None
        self._kernel = None
        self._os_partition = None
        self._primary_disk = None
        self.discriminator = None

        self.bootloaderid = bootloaderid
        self.cmdline = cmdline
        self.image_id = image_id
        self.initrd = initrd
        self.kernel = kernel
        self.os_partition = os_partition
        self.primary_disk = primary_disk

    @property
    def bootloaderid(self):
        """Gets the bootloaderid of this V1BootInfo.  # noqa: E501

        the bootloader ID  # noqa: E501

        :return: The bootloaderid of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._bootloaderid

    @bootloaderid.setter
    def bootloaderid(self, bootloaderid):
        """Sets the bootloaderid of this V1BootInfo.

        the bootloader ID  # noqa: E501

        :param bootloaderid: The bootloaderid of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if bootloaderid is None:
            raise ValueError("Invalid value for `bootloaderid`, must not be `None`")  # noqa: E501

        self._bootloaderid = bootloaderid

    @property
    def cmdline(self):
        """Gets the cmdline of this V1BootInfo.  # noqa: E501

        the cmdline  # noqa: E501

        :return: The cmdline of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._cmdline

    @cmdline.setter
    def cmdline(self, cmdline):
        """Sets the cmdline of this V1BootInfo.

        the cmdline  # noqa: E501

        :param cmdline: The cmdline of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if cmdline is None:
            raise ValueError("Invalid value for `cmdline`, must not be `None`")  # noqa: E501

        self._cmdline = cmdline

    @property
    def image_id(self):
        """Gets the image_id of this V1BootInfo.  # noqa: E501

        the ID of the current image  # noqa: E501

        :return: The image_id of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this V1BootInfo.

        the ID of the current image  # noqa: E501

        :param image_id: The image_id of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if image_id is None:
            raise ValueError("Invalid value for `image_id`, must not be `None`")  # noqa: E501

        self._image_id = image_id

    @property
    def initrd(self):
        """Gets the initrd of this V1BootInfo.  # noqa: E501

        the initrd image  # noqa: E501

        :return: The initrd of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._initrd

    @initrd.setter
    def initrd(self, initrd):
        """Sets the initrd of this V1BootInfo.

        the initrd image  # noqa: E501

        :param initrd: The initrd of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if initrd is None:
            raise ValueError("Invalid value for `initrd`, must not be `None`")  # noqa: E501

        self._initrd = initrd

    @property
    def kernel(self):
        """Gets the kernel of this V1BootInfo.  # noqa: E501

        the kernel  # noqa: E501

        :return: The kernel of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._kernel

    @kernel.setter
    def kernel(self, kernel):
        """Sets the kernel of this V1BootInfo.

        the kernel  # noqa: E501

        :param kernel: The kernel of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if kernel is None:
            raise ValueError("Invalid value for `kernel`, must not be `None`")  # noqa: E501

        self._kernel = kernel

    @property
    def os_partition(self):
        """Gets the os_partition of this V1BootInfo.  # noqa: E501

        the partition containing the OS  # noqa: E501

        :return: The os_partition of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._os_partition

    @os_partition.setter
    def os_partition(self, os_partition):
        """Sets the os_partition of this V1BootInfo.

        the partition containing the OS  # noqa: E501

        :param os_partition: The os_partition of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if os_partition is None:
            raise ValueError("Invalid value for `os_partition`, must not be `None`")  # noqa: E501

        self._os_partition = os_partition

    @property
    def primary_disk(self):
        """Gets the primary_disk of this V1BootInfo.  # noqa: E501

        the primary disk  # noqa: E501

        :return: The primary_disk of this V1BootInfo.  # noqa: E501
        :rtype: str
        """
        return self._primary_disk

    @primary_disk.setter
    def primary_disk(self, primary_disk):
        """Sets the primary_disk of this V1BootInfo.

        the primary disk  # noqa: E501

        :param primary_disk: The primary_disk of this V1BootInfo.  # noqa: E501
        :type: str
        """
        if primary_disk is None:
            raise ValueError("Invalid value for `primary_disk`, must not be `None`")  # noqa: E501

        self._primary_disk = primary_disk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1BootInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1BootInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1PartitionBootConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commandline': 'str',
        'imageurl': 'str',
        'kernelurl': 'str'
    }

    attribute_map = {
        'commandline': 'commandline',
        'imageurl': 'imageurl',
        'kernelurl': 'kernelurl'
    }

    def __init__(self, commandline=None, imageurl=None, kernelurl=None):  # noqa: E501
        """V1PartitionBootConfiguration - a model defined in Swagger"""  # noqa: E501

        self._commandline = None
        self._imageurl = None
        self._kernelurl = None
        self.discriminator = None

        if commandline is not None:
            self.commandline = commandline
        if imageurl is not None:
            self.imageurl = imageurl
        if kernelurl is not None:
            self.kernelurl = kernelurl

    @property
    def commandline(self):
        """Gets the commandline of this V1PartitionBootConfiguration.  # noqa: E501

        the cmdline to the kernel for the boot image  # noqa: E501

        :return: The commandline of this V1PartitionBootConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._commandline

    @commandline.setter
    def commandline(self, commandline):
        """Sets the commandline of this V1PartitionBootConfiguration.

        the cmdline to the kernel for the boot image  # noqa: E501

        :param commandline: The commandline of this V1PartitionBootConfiguration.  # noqa: E501
        :type: str
        """

        self._commandline = commandline

    @property
    def imageurl(self):
        """Gets the imageurl of this V1PartitionBootConfiguration.  # noqa: E501

        the url to download the initrd for the boot image  # noqa: E501

        :return: The imageurl of this V1PartitionBootConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._imageurl

    @imageurl.setter
    def imageurl(self, imageurl):
        """Sets the imageurl of this V1PartitionBootConfiguration.

        the url to download the initrd for the boot image  # noqa: E501

        :param imageurl: The imageurl of this V1PartitionBootConfiguration.  # noqa: E501
        :type: str
        """

        self._imageurl = imageurl

    @property
    def kernelurl(self):
        """Gets the kernelurl of this V1PartitionBootConfiguration.  # noqa: E501

        the url to download the kernel for the boot image  # noqa: E501

        :return: The kernelurl of this V1PartitionBootConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._kernelurl

    @kernelurl.setter
    def kernelurl(self, kernelurl):
        """Sets the kernelurl of this V1PartitionBootConfiguration.

        the url to download the kernel for the boot image  # noqa: E501

        :param kernelurl: The kernelurl of this V1PartitionBootConfiguration.  # noqa: E501
        :type: str
        """

        self._kernelurl = kernelurl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1PartitionBootConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1PartitionBootConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
